import { RcsbFvDisplayTypes } from "@rcsb/rcsb-saguaro";

import { getColorByLocation, getLabelByLocation } from "./UniTmpColor";

export async function fetchDescriptor(entryId: string) {
    const response = await fetch(`https://htp.unitmp.org/api/v1/entry/${entryId}.json`);
    const descriptor = await response.json();
    return descriptor;
}

export function descriptorChainToTrackData(descriptor: any) {
    const tracks = [] as any[];
    descriptor.Predictions.Prediction.forEach((prediction: any) => {
        const trackData = {
            trackHeight: 20,
            trackColor: "#F9F9F9",
            displayType: RcsbFvDisplayTypes.COMPOSITE,
            rowTitle: prediction['@attributes'].name,
            displayConfig: [] as any[]
        };
        tracks.push(trackData);

        if (!Array.isArray(prediction.Region)) {
            return;
        }

        prediction.Region.forEach((region: any) => {
            trackData.displayConfig.push(createDisplayItem({
                begin: parseInt(region['@attributes'].from),
                end: parseInt(region['@attributes'].to),
                location: region['@attributes'].loc
            }));
        });
    });

    console.log(tracks);
    return tracks;
}

function createDisplayItem(params: any) {
    return {
        displayType: RcsbFvDisplayTypes.BLOCK,
        displayColor: getColorByLocation(params.location),
        displayId: `${params.begin}_${params.end}_${params.location}`,
        displayData: [{
            begin: params.begin,
            end: params.end,
            name: getLabelByLocation(params.location)
        }]
    };
}
