import {RcsbFv3DCustom} from "../../RcsbFv3D/RcsbFv3DCustom";
import {RcsbFvStructureConfigInterface} from "../../RcsbFvStructure/RcsbFvStructure";
import {
    CustomViewInterface,
    FeatureBlockInterface
} from "../../RcsbFvSequence/SequenceViews/CustomView/CustomView";
import {
    LoadMethod,
    LoadMolstarInterface, LoadMolstarReturnType
} from "../../RcsbFvStructure/StructureViewers/MolstarViewer/MolstarActionManager";
import {ViewerProps} from "@rcsb/rcsb-molstar/build/src/viewer";

import { descriptorChainToTrackData, fetchDescriptor } from "./UniTmpHelper";
import { updateSiteColors } from "./UniTmpColor";
import { fvConfig, rowConfig } from "./FeatureViewConfig";


const block: FeatureBlockInterface<LoadMolstarInterface<unknown,unknown>,LoadMolstarReturnType> = {
    blockId:"MyBlock_1",
    featureViewConfig: [fvConfig]
};

const customConfig: CustomViewInterface<LoadMolstarInterface<unknown,unknown>,LoadMolstarReturnType> = {
    blockConfig:[block]
}

const sequenceConfig = {
    title: "UniTmp example",
    subtitle: "HTP entry",
    config: customConfig
};

const molstarConfig: RcsbFvStructureConfigInterface<LoadMolstarInterface<unknown,unknown>,{viewerProps:Partial<ViewerProps>}> = {
    loadConfig: {
        loadMethod: LoadMethod.loadPdbId,
        loadParams: {
            entryId: "2xq2",
            id:"2xq2_model"
        }
    },
    structureViewerConfig: {
        viewerProps:{
            showImportControls: true,
            showSessionControls: false
        }
    }
};

document.addEventListener("DOMContentLoaded", async function(event) {
    updateSiteColors("Inside");
    const descriptor = await fetchDescriptor("SC5AA_HUMAN");

    console.log(descriptor);

    let sequence = descriptor.Sequence.Seq;
    sequence = sequence.replace(/\s+/g, '');

    fvConfig.boardConfig.length = parseInt(descriptor.Sequence['@attributes'].Length);
    fvConfig.rowConfig[0].rowTitle = `${descriptor['@attributes'].id} sequence`;
    rowConfig[0].trackData![0].value = sequence;
    rowConfig.push(...descriptorChainToTrackData(descriptor));


    const panel3d = new RcsbFv3DCustom({
        elementId: "null",
        structurePanelConfig: molstarConfig,
        sequencePanelConfig: sequenceConfig
    });
    panel3d.render();
});
